Package: DrugUtilisation
Title: Summarise Patient-Level Drug Utilisation in Data Mapped to the
        OMOP Common Data Model
Version: 1.2.0
Authors@R: c(
    person(
        "Martí", "Català", email = "marti.catalasabate@ndorms.ox.ac.uk", 
        role = c("aut", "cre"), comment = c(ORCID = "0000-0003-3308-9905")
    ),
    person(
        "Mike", "Du", email = "mike.du@ndorms.ox.ac.uk", role = c("ctb"), 
        comment = c(ORCID = "0000-0002-9517-8834")
    ),
    person(
        "Yuchen", "Guo", email = "yuchen.guo@ndorms.ox.ac.uk", role = c("aut"), 
        comment = c(ORCID = "0000-0002-0847-4855")
    ),
    person(
        "Kim", "Lopez-Guell", , "kim.lopez@spc.ox.ac.uk", role = c("aut"),
        comment = c(ORCID = "0000-0002-8462-8668")
    ),
    person(
        "Edward", "Burn", email = "edward.burn@ndorms.ox.ac.uk", 
        role = c("aut"), comment = c(ORCID = "0000-0002-9286-1128")
    ), 
    person(
        "Xintong", "Li", email = "xintong.li@ndorms.ox.ac.uk", role = c("ctb"),
        comment = c(ORCID = "0000-0002-6872-5804")
    ),
    person(
        "Marta", "Alcalde-Herraiz", 
        email = "marta.alcaldeherraiz@ndorms.ox.ac.uk", 
        role = c("ctb"), comment = c(ORCID = "0009-0002-4405-1814")
    ),
    person(
        "Nuria", "Mercade-Besora", , 
        email = "nuria.mercadebesora@ndorms.ox.ac.uk", role = c("aut"), 
        comment = c(ORCID = "0009-0006-7948-3747")
    ),
    person(
        "Xihang", "Chen", , 
        email = "xihang.chen@ndorms.ox.ac.uk", role = c("aut"), 
        comment = c(ORCID = "0009-0001-8112-8959")
    ))
Description: Summarise patient-level drug utilisation cohorts using data mapped 
    to the Observational Medical Outcomes Partnership (OMOP) common data model. 
    New users and prevalent users cohorts can be generated and their 
    characteristics, indication and drug use summarised.
License: Apache License (>= 2)
Encoding: UTF-8
RoxygenNote: 7.3.3
Suggests: bit64, CDMConnector (>= 1.4.0), CohortConstructor,
        CohortSurvival, covr, DBI, downlit, duckdb, extrafont,
        flextable, ggplot2, ggtext, gt, here, knitr, odbc, omock,
        plotly, rmarkdown, RPostgres, scales, testthat (>= 3.1.5),
        tibble, visOmopResults (>= 1.3.0), xml2
Config/testthat/edition: 3
Imports: cli, clock, CodelistGenerator (>= 3.1.0), dplyr, glue,
        lifecycle, omopgenerics (>= 1.3.1), PatientProfiles (>= 1.4.2),
        purrr, rlang, stringr, tidyr
Depends: R (>= 4.1)
LazyData: true
URL: https://darwin-eu.github.io/DrugUtilisation/
BugReports: https://github.com/darwin-eu/DrugUtilisation/issues
Config/testthat/parallel: true
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-06-17 22:07:14 UTC; martics
Author: Martí Català [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-3308-9905>),
  Mike Du [ctb] (ORCID: <https://orcid.org/0000-0002-9517-8834>),
  Yuchen Guo [aut] (ORCID: <https://orcid.org/0000-0002-0847-4855>),
  Kim Lopez-Guell [aut] (ORCID: <https://orcid.org/0000-0002-8462-8668>),
  Edward Burn [aut] (ORCID: <https://orcid.org/0000-0002-9286-1128>),
  Xintong Li [ctb] (ORCID: <https://orcid.org/0000-0002-6872-5804>),
  Marta Alcalde-Herraiz [ctb] (ORCID:
    <https://orcid.org/0009-0002-4405-1814>),
  Nuria Mercade-Besora [aut] (ORCID:
    <https://orcid.org/0009-0006-7948-3747>),
  Xihang Chen [aut] (ORCID: <https://orcid.org/0009-0001-8112-8959>)
Maintainer: Martí Català <marti.catalasabate@ndorms.ox.ac.uk>
Repository: CRAN
Date/Publication: 2026-06-18 05:10:36 UTC
Built: R 4.5.2; ; 2026-06-18 05:26:30 UTC; unix
