# Generated by roxygen2: do not edit by hand

export(addCumulativeDose)
export(addCumulativeQuantity)
export(addDailyDose)
export(addDaysExposed)
export(addDaysPrescribed)
export(addDrugRestart)
export(addDrugUtilisation)
export(addIndication)
export(addInitialDailyDose)
export(addInitialExposureDuration)
export(addInitialQuantity)
export(addNumberEras)
export(addNumberExposures)
export(addTimeToExposure)
export(addTreatment)
export(additionalColumns)
export(attrition)
export(benchmarkDrugUtilisation)
export(bind)
export(cohortCodelist)
export(cohortCount)
export(cohortGapEra)
export(erafyCohort)
export(exportSummarisedResult)
export(generateAtcCohortSet)
export(generateDrugUtilisationCohortSet)
export(generateIngredientCohortSet)
export(groupColumns)
export(importSummarisedResult)
export(mockDrugUtilisation)
export(patternTable)
export(plotDiscontinuationAsSurvival)
export(plotDrugRestart)
export(plotDrugUtilisation)
export(plotIndication)
export(plotProportionOfPatientsCovered)
export(plotTreatment)
export(requireDrugInDateRange)
export(requireIsFirstDrugEntry)
export(requireObservationBeforeDrug)
export(requirePriorDrugWashout)
export(settings)
export(settingsColumns)
export(strataColumns)
export(summariseDiscontinuationAsSurvival)
export(summariseDoseCoverage)
export(summariseDrugRestart)
export(summariseDrugUtilisation)
export(summariseIndication)
export(summariseProportionOfPatientsCovered)
export(summariseTreatment)
export(suppress)
export(tableDiscontinuationAsSurvival)
export(tableDoseCoverage)
export(tableDrugRestart)
export(tableDrugUtilisation)
export(tableIndication)
export(tableProportionOfPatientsCovered)
export(tableTreatment)
export(tidy)
importFrom(omopgenerics,additionalColumns)
importFrom(omopgenerics,attrition)
importFrom(omopgenerics,bind)
importFrom(omopgenerics,cohortCodelist)
importFrom(omopgenerics,cohortCount)
importFrom(omopgenerics,exportSummarisedResult)
importFrom(omopgenerics,groupColumns)
importFrom(omopgenerics,importSummarisedResult)
importFrom(omopgenerics,settings)
importFrom(omopgenerics,settingsColumns)
importFrom(omopgenerics,strataColumns)
importFrom(omopgenerics,suppress)
importFrom(omopgenerics,tidy)
importFrom(rlang,"%||%")
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(rlang,.env)
